import { AttributeValue } from "@aws-sdk/client-dynamodb";
interface IAttributeNames {
    [key: string]: string;
}
interface IAttributeValues {
    [key: string]: AttributeValue;
}
interface IBuildResult {
    UpdateExpression?: string;
    ExpressionAttributeNames?: IAttributeNames;
    ExpressionAttributeValues?: IAttributeValues;
}
export default class AttributeExpression {
    private rawExpressions;
    /**
     * Creates a new AttributeExpression instance using the specified plain data generated by AwsModelConverter.
     * The update expression will represnt a SET action.
     */
    static setFromPlain(data: Record<string, AttributeValue>): AttributeExpression;
    /**
     * Adds the specified key/value attribute entry for SET action.
     */
    setAttribute(key: string, value: AttributeValue): void;
    /**
     * Adds the specified key/value attribute entry for ADD action.
     */
    addAttribute(key: string, value: AttributeValue): void;
    /**
     * Adds the specified attribute key for REMOVE action.
     */
    removeAttribute(key: string): void;
    /**
     * Deletes the specified attribute key for DELETE action.
     */
    deleteAttribute(key: string, value: AttributeValue): void;
    /**
     * Returns the expression values for inputting into DDB commands.
     */
    build(): IBuildResult;
}
export {};
