var AttributeExpression = /** @class */ (function () {
    function AttributeExpression() {
        this.rawExpressions = {};
    }
    /**
     * Creates a new AttributeExpression instance using the specified plain data generated by AwsModelConverter.
     * The update expression will represnt a SET action.
     */
    AttributeExpression.setFromPlain = function (data) {
        var expression = new AttributeExpression();
        for (var key in data) {
            expression.setAttribute(key, data[key]);
        }
        return expression;
    };
    /**
     * Adds the specified key/value attribute entry for SET action.
     */
    AttributeExpression.prototype.setAttribute = function (key, value) {
        if (this.rawExpressions.SET === undefined) {
            this.rawExpressions.SET = {};
        }
        this.rawExpressions.SET[key] = value;
    };
    /**
     * Adds the specified key/value attribute entry for ADD action.
     */
    AttributeExpression.prototype.addAttribute = function (key, value) {
        if (this.rawExpressions.ADD === undefined) {
            this.rawExpressions.ADD = {};
        }
        this.rawExpressions.ADD[key] = value;
    };
    /**
     * Adds the specified attribute key for REMOVE action.
     */
    AttributeExpression.prototype.removeAttribute = function (key) {
        if (this.rawExpressions.REMOVE === undefined) {
            this.rawExpressions.REMOVE = [];
        }
        this.rawExpressions.REMOVE.push(key);
    };
    /**
     * Deletes the specified attribute key for DELETE action.
     */
    AttributeExpression.prototype.deleteAttribute = function (key, value) {
        if (this.rawExpressions.DELETE === undefined) {
            this.rawExpressions.DELETE = {};
        }
        this.rawExpressions.DELETE[key] = value;
    };
    /**
     * Returns the expression values for inputting into DDB commands.
     */
    AttributeExpression.prototype.build = function () {
        var _this = this;
        var expressions = [];
        var names = {};
        var values = {};
        if (this.rawExpressions.ADD !== undefined) {
            expressions.push("ADD " + Object.keys(this.rawExpressions.ADD).map(function (key) {
                names["#" + key] = key;
                values[":" + key] = _this.rawExpressions.ADD[key];
                return "#" + key + " :" + key;
            }).join(", "));
        }
        if (this.rawExpressions.DELETE !== undefined) {
            expressions.push("DELETE " + Object.keys(this.rawExpressions.DELETE).map(function (key) {
                names["#" + key] = key;
                values[":" + key] = _this.rawExpressions.DELETE[key];
                return "#" + key + " :" + key;
            }).join(", "));
        }
        if (this.rawExpressions.REMOVE !== undefined) {
            expressions.push("REMOVE " + this.rawExpressions.REMOVE.map(function (key) {
                names["#" + key] = key;
                return "#" + key;
            }).join(", "));
        }
        if (this.rawExpressions.SET !== undefined) {
            expressions.push("SET " + Object.keys(this.rawExpressions.SET).map(function (key) {
                names["#" + key] = key;
                values[":" + key] = _this.rawExpressions.SET[key];
                return "#" + key + " = :" + key;
            }).join(", "));
        }
        return {
            UpdateExpression: expressions.length === 0 ? undefined : expressions.join(", "),
            ExpressionAttributeNames: Object.keys(names).length === 0 ? undefined : names,
            ExpressionAttributeValues: Object.keys(values).length === 0 ? undefined : values,
        };
    };
    return AttributeExpression;
}());
export default AttributeExpression;
