import { ModelConverter } from "yuni-chanz-react";
import { AttributeValue } from "@aws-sdk/client-dynamodb";
export default abstract class AwsModelConverter<T = any> extends ModelConverter<T> {
    /**
     * Encodes the specified number value to a DDB attribute value.
     */
    encodeNumber(value: number): AttributeValue;
    /**
     * Encodes the specified string value to a DDB attribute value.
     */
    encodeString(value: string): AttributeValue;
    /**
     * Encodes the specified bool value to a DDB attribute value.
     */
    encodeBool(value: boolean): AttributeValue;
    /**
     * Encodes the specified string array value to a DDB attribute value.
     */
    encodeStringArray(value: string[]): AttributeValue;
    /**
     * Encodes the specified number array value to a DDB attribute value.
     */
    encodeNumberArray(value: number[]): AttributeValue;
    /**
     * Encodes the specified date instance to a storable type.
     */
    encodeDate(value: Date): AttributeValue;
    /**
     * Decodes the specified raw value to an int.
     */
    decodeInt(value: (AttributeValue)): number | null;
    /**
     * Decodes the specified raw value to a float.
     */
    decodeFloat(value: (AttributeValue)): number | null;
    /**
     * Decodes the specified raw value to a string.
     */
    decodeString(value: (AttributeValue)): string | null;
    /**
     * Decodes the specified raw value to a bool.
     */
    decodeBool(value: (AttributeValue)): boolean | null;
    /**
     * Decodes the specified raw value to a string array.
     */
    decodeStringArray(value: (AttributeValue)): string[] | null;
    /**
     * Decodes the specified raw value to an integer array.
     */
    decodeIntArray(value: (AttributeValue), radix?: number): number[] | null;
    /**
     * Decodes the specified raw value to a float array.
     */
    decodeFloatArray(value: (AttributeValue)): number[] | null;
    /**
     * Decodes the specified raw value to a Date instance.
     */
    decodeDate(value: (AttributeValue)): Date | null;
}
